==> qtjambi-script-5.15.14-sources.jar: io/qt/script/QScriptExtensionPlugin.java <==
package io.qt.script;

import io.qt.*;


/**
 * <p>Abstract base for custom QScript extension plugins</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html">QScriptExtensionPlugin</a></p>
 */
public abstract class QScriptExtensionPlugin extends io.qt.core.QObject
    implements io.qt.script.QScriptExtensionInterface,
            io.qt.core.QFactoryInterface
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScriptExtensionPlugin.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QScriptExtensionPlugin {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public void initialize(java.lang.@NonNull String key, io.qt.script.@Nullable QScriptEngine engine){
            initialize_native_cref_QString_QScriptEngine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), key, QtJambi_LibraryUtilities.internal.checkedNativeId(engine));
        }
        private native static void initialize_native_cref_QString_QScriptEngine_ptr(long __this__nativeId, java.lang.String key, long engine);
        
        
        @Override
        @QtUninvokable
        public java.util.@NonNull List<java.lang.@NonNull String> keys(){
            return keys_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static java.util.List<java.lang.String> keys_native_constfct(long __this__nativeId);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScriptExtensionPlugin() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#QScriptExtensionPlugin">QScriptExtensionPlugin::QScriptExtensionPlugin(QObject*)</a></p>
     */
    public QScriptExtensionPlugin(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
        if (parent != null) QtJambi_LibraryUtilities.internal.setCppOwnership(this);
    }
    
    private native static void initialize_native(QScriptExtensionPlugin instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#setupPackage">QScriptExtensionPlugin::setupPackage(QString,QScriptEngine*)const</a></p>
     */
    @QtUninvokable
    public final io.qt.script.@NonNull QScriptValue setupPackage(java.lang.@NonNull String key, io.qt.script.@Nullable QScriptEngine engine){
        return setupPackage_native_cref_QString_QScriptEngine_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), key, QtJambi_LibraryUtilities.internal.checkedNativeId(engine));
    }
    
    @QtUninvokable
    private native io.qt.script.QScriptValue setupPackage_native_cref_QString_QScriptEngine_ptr_constfct(long __this__nativeId, java.lang.String key, long engine);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#initialize">QScriptExtensionInterface::initialize(QString,QScriptEngine*)</a></p>
     */
    @QtUninvokable
    public abstract void initialize(java.lang.@NonNull String key, io.qt.script.@Nullable QScriptEngine engine);
    
    private native static void initialize_native_cref_QString_QScriptEngine_ptr(long __this__nativeId, java.lang.String key, long engine);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#keys">QFactoryInterface::keys()const</a></p>
     */
    @QtUninvokable
    public abstract java.util.@NonNull List<java.lang.@NonNull String> keys();
    
    private native static java.util.List<java.lang.String> keys_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QScriptExtensionPlugin(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QScriptExtensionPlugin(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QScriptExtensionPlugin instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-script-5.15.15-sources.jar: io/qt/script/QScriptExtensionPlugin.java <==
package io.qt.script;

import io.qt.*;


/**
 * <p>Abstract base for custom QScript extension plugins</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html">QScriptExtensionPlugin</a></p>
 */
public abstract class QScriptExtensionPlugin extends io.qt.core.QObject
    implements io.qt.script.QScriptExtensionInterface,
            io.qt.core.QFactoryInterface
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScriptExtensionPlugin.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QScriptExtensionPlugin {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public void initialize(java.lang.@NonNull String key, io.qt.script.@Nullable QScriptEngine engine){
            initialize_native_cref_QString_QScriptEngine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), key, QtJambi_LibraryUtilities.internal.checkedNativeId(engine));
        }
        private native static void initialize_native_cref_QString_QScriptEngine_ptr(long __this__nativeId, java.lang.String key, long engine);
        
        
        @Override
        @QtUninvokable
        public java.util.@NonNull List<java.lang.@NonNull String> keys(){
            return keys_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static java.util.List<java.lang.String> keys_native_constfct(long __this__nativeId);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QScriptExtensionPlugin(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScriptExtensionPlugin() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#QScriptExtensionPlugin">QScriptExtensionPlugin::QScriptExtensionPlugin(QObject*)</a></p>
     */
    public QScriptExtensionPlugin(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
        if (parent != null) QtJambi_LibraryUtilities.internal.setCppOwnership(this);
    }
    
    private native static void initialize_native(QScriptExtensionPlugin instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#setupPackage">QScriptExtensionPlugin::setupPackage(QString,QScriptEngine*)const</a></p>
     */
    @QtUninvokable
    public final io.qt.script.@NonNull QScriptValue setupPackage(java.lang.@NonNull String key, io.qt.script.@Nullable QScriptEngine engine){
        return setupPackage_native_cref_QString_QScriptEngine_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), key, QtJambi_LibraryUtilities.internal.checkedNativeId(engine));
    }
    
    @QtUninvokable
    private native io.qt.script.QScriptValue setupPackage_native_cref_QString_QScriptEngine_ptr_constfct(long __this__nativeId, java.lang.String key, long engine);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#initialize">QScriptExtensionInterface::initialize(QString,QScriptEngine*)</a></p>
     */
    @QtUninvokable
    public abstract void initialize(java.lang.@NonNull String key, io.qt.script.@Nullable QScriptEngine engine);
    
    private native static void initialize_native_cref_QString_QScriptEngine_ptr(long __this__nativeId, java.lang.String key, long engine);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qscriptextensionplugin.html#keys">QFactoryInterface::keys()const</a></p>
     */
    @QtUninvokable
    public abstract java.util.@NonNull List<java.lang.@NonNull String> keys();
    
    private native static java.util.List<java.lang.String> keys_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QScriptExtensionPlugin(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QScriptExtensionPlugin(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QScriptExtensionPlugin instance, QDeclarativeConstructor constructor);
    
}
